@@ -1,6 +1,13 @@
-/* demo/grph1/sgpack/sgpk02.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20160102).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
 #include "libtinyf2c.h"
@@ -22,7 +29,7 @@ static real c_b33 = .9f;
 static logical c_true = TRUE_;
 
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Main program */ int MAIN__(void)
 {
@@ -59,13 +66,13 @@ static logical c_true = TRUE_;
     sgswnd_(&c_b7, &c_b8, &c_b7, &c_b8);
 /*  <--+ */
     sgsvpt_(&c_b7, &c_b8, &c_b7, &c_b8);
-/*     | Ѵؿ */
+/*     | */
     sgstrn_(&c__1);
 /*     | */
     sgstrf_();
 /*  <--+ */
     slpvpr_(&c__1);
-/*  <--- Ȥ */
+/*  <--- */
     sglnzu_(&c_b17, &c_b18, &c_b18, &c_b17, &c__2);
 /*  <--- X */
     sglnu_(&c_b17, &c_b17, &c_b18, &c_b18);
@@ -74,9 +81,9 @@ static logical c_true = TRUE_;
     sgfrm_();
 /*                  XMIN, XMAX, YMIN, YMAX */
     sgswnd_(&c_b7, &c_b8, &c_b7, &c_b8);
-/*  <-- Ω */
+/*  <-- */
     sgsvpt_(&c_b30, &c_b31, &c_b32, &c_b33);
-/*  <--  */
+/*  <-- */
     sgstrf_();
     slpvpr_(&c__1);
     sglnzu_(&c_b17, &c_b18, &c_b18, &c_b17, &c__2);
@@ -84,9 +91,9 @@ static logical c_true = TRUE_;
 /*   ------------------------------------------ */
 /*                  XMIN, XMAX, YMIN, YMAX */
     sgswnd_(&c_b7, &c_b8, &c_b8, &c_b7);
-/*  <-- 岼 */
+/*  <-- */
     sgsvpt_(&c_b32, &c_b33, &c_b32, &c_b33);
-/*  <--  */
+/*  <-- */
     sgstrf_();
     slpvpr_(&c__1);
     sglnzu_(&c_b17, &c_b18, &c_b18, &c_b17, &c__2);
@@ -94,9 +101,9 @@ static logical c_true = TRUE_;
 /*   ------------------------------------------ */
 /*                  XMIN, XMAX, YMIN, YMAX */
     sgswnd_(&c_b7, &c_b8, &c_b7, &c_b32);
-/*  <-- ʥ */
+/*  <-- */
     sgsvpt_(&c_b30, &c_b31, &c_b30, &c_b31);
-/*  <--  */
+/*  <-- */
     sgstrf_();
     slpvpr_(&c__1);
     sglnzu_(&c_b17, &c_b18, &c_b18, &c_b17, &c__2);
@@ -104,13 +111,13 @@ static logical c_true = TRUE_;
 /*   ------------------------------------------ */
 /*                  XMIN, XMAX, YMIN, YMAX */
     sgswnd_(&c_b7, &c_b8, &c_b7, &c_b32);
-/*  <-- ʥ */
+/*  <-- */
     sgsvpt_(&c_b32, &c_b33, &c_b30, &c_b31);
-/*  <--  */
+/*  <-- */
     sgstrf_();
     slpvpr_(&c__1);
     sglset_("LCLIP", &c_true, (ftnlen)5);
-/*  <-- åԥ󥰤λ */
+/*  <-- */
     sglnzu_(&c_b17, &c_b18, &c_b18, &c_b17, &c__2);
     sglnu_(&c_b17, &c_b17, &c_b18, &c_b18);
     sgcls_();
