@@ -1,6 +1,13 @@
-/* demo/grph1/sgpack/sgpk06.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20160102).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
 #include "libtinyf2c.h"
@@ -25,7 +32,7 @@ static real c_b48 = .5f;
 static logical c_true = TRUE_;
 
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Main program */ int MAIN__(void)
 {
@@ -78,57 +85,57 @@ static logical c_true = TRUE_;
     sgstrf_();
     slpvpr_(&c__1);
     sgplu_(&c__37, x, y);
-/* <--  */
+/* <-- */
     sgtxu_(&xc, &yc, "SGTXU", (ftnlen)5);
 /* ----------------------------- page 2 --------------------------------- */
-/* <-- ƥ */
+/* <-- */
     sgfrm_();
 /*                 XMIN, XMAX, YMIN, YMAX */
     sgswnd_(&c_b9, &c_b10, &c_b9, &c_b10);
 /* <-- 1x1 */
     sgsvpt_(&c_b25, &c_b26, &c_b27, &c_b28);
-/* <--  view port */
+/* <-- 小さな view port */
     sgstrn_(&c__1);
     sgstrf_();
     slpvpr_(&c__1);
     sgplu_(&c__37, x, y);
-/* <--  */
+/* <-- */
     sgtxu_(&xc, &yc, "SGTXU", (ftnlen)5);
 /*                XMIN, XMAX, YMIN, YMAX */
-/* <-- ƥ */
+/* <-- */
     sgswnd_(&c_b9, &c_b10, &c_b35, &c_b36);
-/* <-- 椬 window */
+/* <-- ゆがんだ window */
     sgsvpt_(&c_b27, &c_b28, &c_b27, &c_b28);
     sgstrn_(&c__1);
     sgstrf_();
     slpvpr_(&c__1);
     sgplu_(&c__37, x, y);
-/* <--  */
+/* <-- */
     sgtxu_(&xc, &yc, "SGTXU", (ftnlen)5);
 /*                XMIN, XMAX, YMIN, YMAX */
-/* <-- ƥ */
+/* <-- */
     sgswnd_(&c_b9, &c_b10, &c_b47, &c_b48);
-/* <-- Ϥ߽Ф window */
+/* <-- はみ出し window */
     sgsvpt_(&c_b25, &c_b26, &c_b25, &c_b26);
     sgstrn_(&c__1);
     sgstrf_();
     slpvpr_(&c__1);
     sgplu_(&c__37, x, y);
-/* <--  */
+/* <-- */
     sgtxu_(&xc, &yc, "SGTXU", (ftnlen)5);
-/* <-- ƥ */
+/* <-- */
     sglset_("LCLIP", &c_true, (ftnlen)5);
 /*                XMIN, XMAX, YMIN, YMAX */
-/* <-- åԥ */
+/* <-- */
     sgswnd_(&c_b9, &c_b10, &c_b47, &c_b48);
     sgsvpt_(&c_b27, &c_b28, &c_b25, &c_b26);
     sgstrn_(&c__1);
     sgstrf_();
     slpvpr_(&c__1);
     sgplu_(&c__37, x, y);
-/* <--  */
+/* <-- */
     sgtxu_(&xc, &yc, "SGTXU", (ftnlen)5);
-/* <-- ƥ */
+/* <-- */
     sgcls_();
     return 0;
 } /* MAIN__ */
