@@ -1,6 +1,13 @@
-/* demo/grph1/slpack/slpk03.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20160102).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
 #include "libtinyf2c.h"
@@ -25,7 +32,7 @@ static real c_b41 = .58f;
 static real c_b47 = .99f;
 
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Main program */ int MAIN__(void)
 {
@@ -58,7 +65,7 @@ static real c_b47 = .99f;
     sglset_("LFULL", &c_true, (ftnlen)5);
     slmgn_(&c_b8, &c_b8, &c_b10, &c_b10);
     slrat_(&c_b12, &c_b13);
-/* <-- Ĳ */
+/* <-- */
     slsttl_("FIGURE TITLE", "T", &c_b8, &c_b17, &c_b18, &c__1, (ftnlen)12, (
 	    ftnlen)1);
     slsttl_("page:#PAGE", "B", &c_b12, &c_b12, &c_b18, &c__2, (ftnlen)10, (
