@@ -1,4 +1,4 @@
-/*  -- translated by f2c (version 20100827).
+/*  -- translated by f2c (version 20160102).
    You must link the resulting object file with libf2c:
 	on Microsoft Windows system, link with libf2c.lib;
 	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
@@ -21,10 +21,18 @@ static integer c__1 = 1;
 static integer c__3 = 3;
 static real c_b14 = -1.f;
 static real c_b15 = 1.f;
-static real c_b18 = .1f;
-static real c_b19 = .9f;
+static real c_b18 = .125f;
+static real c_b19 = .875f;
+static real c_b20 = .2f;
+static real c_b21 = .95f;
 static integer c__50 = 50;
+static real c_b27 = .1f;
 static real c_b28 = .5f;
+static integer c__5 = 5;
+static real c_b40 = .3f;
+static real c_b41 = .7f;
+static real c_b43 = .14f;
+static real c_b47 = 0.f;
 
 /* Main program */ int MAIN__(void)
 {
@@ -39,13 +47,17 @@ static real c_b28 = .5f;
     static integer i__, j;
     static real z__[2500]	/* was [50][50] */;
     static integer iws;
+    static real zmin, zmax;
     extern /* Subroutine */ int grcls_(void), grfrm_(void), gropn_(integer *),
-	     uipdat_(real *, integer *, integer *, integer *), grswnd_(real *,
-	     real *, real *, real *), uilset_(char *, logical *, ftnlen), 
-	    grstrf_(void), swiset_(char *, integer *, ftnlen), grstrn_(
-	    integer *), uxaxdv_(char *, real *, real *, ftnlen), sgpwsn_(void)
-	    , uyaxdv_(char *, real *, real *, ftnlen), grsvpt_(real *, real *,
-	     real *, real *);
+	     uipdat_(real *, integer *, integer *, integer *), uiqcrg_(real *,
+	     real *), uixbar_(real *, real *, real *, real *, real *, real *, 
+	    char *, ftnlen), grswnd_(real *, real *, real *, real *), uilset_(
+	    char *, logical *, ftnlen), grstrf_(void), swiset_(char *, 
+	    integer *, ftnlen), grstrn_(integer *), uxaxdv_(char *, real *, 
+	    real *, ftnlen), sgpwsn_(void), uyaxdv_(char *, real *, real *, 
+	    ftnlen), uspset_(char *, integer *, ftnlen), grsvpt_(real *, real 
+	    *, real *, real *), uxsttl_(char *, char *, real *, ftnlen, 
+	    ftnlen);
 
     /* Fortran I/O blocks */
     static cilist io___4 = { 0, 6, 0, 0, 0 };
@@ -75,14 +87,18 @@ static real c_b28 = .5f;
     gropn_(&iws);
     grfrm_();
     grswnd_(&c_b14, &c_b15, &c_b14, &c_b15);
-    grsvpt_(&c_b18, &c_b19, &c_b18, &c_b19);
+    grsvpt_(&c_b18, &c_b19, &c_b20, &c_b21);
     grstrn_(&c__1);
     grstrf_();
     uipdat_(z__, &c__50, &c__50, &c__50);
-    uxaxdv_("T", &c_b18, &c_b28, (ftnlen)1);
-    uxaxdv_("B", &c_b18, &c_b28, (ftnlen)1);
-    uyaxdv_("L", &c_b18, &c_b28, (ftnlen)1);
-    uyaxdv_("R", &c_b18, &c_b28, (ftnlen)1);
+    uxaxdv_("T", &c_b27, &c_b28, (ftnlen)1);
+    uxaxdv_("B", &c_b27, &c_b28, (ftnlen)1);
+    uyaxdv_("L", &c_b27, &c_b28, (ftnlen)1);
+    uyaxdv_("R", &c_b27, &c_b28, (ftnlen)1);
+    uspset_("MXDGTX", &c__5, (ftnlen)6);
+    uiqcrg_(&zmin, &zmax);
+    uixbar_(&c_b40, &c_b41, &c_b27, &c_b43, &zmin, &zmax, "B", (ftnlen)1);
+    uxsttl_("B", "color scale", &c_b47, (ftnlen)1, (ftnlen)11);
     grcls_();
     return 0;
 } /* MAIN__ */
