@@ -1,4 +1,4 @@
-/*  -- translated by f2c (version 20050501).
+/*  -- translated by f2c (version 20160102).
    You must link the resulting object file with libf2c:
 	on Microsoft Windows system, link with libf2c.lib;
 	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
@@ -33,16 +33,17 @@ static real c_b35 = .03f;
 static integer c__0 = 0;
 
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Main program */ int MAIN__(void)
 {
     /* Initialized data */
 
-    static char ctr[3*14] = "CYL" "MER" "MWD" "HMR" "EK6" "KTD" "CON" "COA" 
-	    "COC" "BON" "OTG" "PST" "AZM" "AZA";
-    static real fct[14] = { .12f,.12f,.14f,.14f,.14f,.14f,.11f,.16f,.12f,.12f,
-	    .4f,.12f,.12f,.17f };
+    static char ctr[3*20] = "CYL" "MER" "MWD" "HMR" "EK6" "KTD" "MIL" "RBS" 
+	    "SIN" "VDG" "CON" "COA" "COC" "BON" "PLC" "OTG" "PST" "AZM" "AZA" 
+	    "GNO";
+    static real fct[20] = { .12f,.12f,.14f,.14f,.14f,.14f,.12f,.12f,.12f,.12f,
+	    .11f,.16f,.12f,.12f,.12f,.4f,.12f,.12f,.17f,.18f };
 
     /* System generated locals */
     integer i__1;
@@ -82,7 +83,7 @@ static integer c__0 = 0;
     sgopn_(&iws);
     sgrset_("STLAT1", &c_b7, (ftnlen)6);
     sgrset_("STLAT2", &c_b9, (ftnlen)6);
-    for (i__ = 1; i__ <= 14; ++i__) {
+    for (i__ = 1; i__ <= 20; ++i__) {
 	sgfrm_();
 	sgssim_(&fct[i__ - 1], &c_b11, &c_b11);
 	sgsmpl_(&c_b11, &c_b14, &c_b11);
