@@ -1,4 +1,4 @@
-/*  -- translated by f2c (version 20100827).
+/*  -- translated by f2c (version 20160102).
    You must link the resulting object file with libf2c:
 	on Microsoft Windows system, link with libf2c.lib;
 	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
@@ -20,7 +20,7 @@ static integer c__3 = 3;
 static integer c__200 = 200;
 
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Main program */ int MAIN__(void)
 {
@@ -78,7 +78,7 @@ static integer c__200 = 200;
     e_rsle();
     gropn_(&iws);
     grfrm_();
-    ussttl_("TIME", "SEC", "HEAT FLUX", "W/m|2\"", (ftnlen)4, (ftnlen)3, (
+    ussttl_("TIME", "SEC", "HEAT FLUX", "W/m\\^2", (ftnlen)4, (ftnlen)3, (
 	    ftnlen)9, (ftnlen)6);
     usgrph_(&c__200, t, a);
     grcls_();
