@@ -1,4 +1,4 @@
-/*  -- translated by f2c (version 20100827).
+/*  -- translated by f2c (version 20160102).
    You must link the resulting object file with libf2c:
 	on Microsoft Windows system, link with libf2c.lib;
 	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
@@ -85,7 +85,7 @@ static integer c__200 = 200;
     uscset_("CYSPOS", "B", (ftnlen)6, (ftnlen)1);
     uscset_("CXSIDE", "T", (ftnlen)6, (ftnlen)1);
     uscset_("CYSIDE", "L", (ftnlen)6, (ftnlen)1);
-    swlget_("SYSFONT", &lsfnt, (ftnlen)7);
+    swlget_("LSYSFNT", &lsfnt, (ftnlen)7);
 /* Writing concatenation */
     i__1[0] = 2, a__1[0] = "\\^";
     usgi_(ch__2, (ftnlen)3, &c__228);
