@@ -1,6 +1,13 @@
-/* demo/math1/rfblib/rfbl01.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20160102).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
 #include "libtinyf2c.h"
@@ -11,7 +18,7 @@ static integer c__1 = 1;
 static integer c__8 = 8;
 
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Main program */ int MAIN__(void)
 {
@@ -27,9 +34,9 @@ static integer c__8 = 8;
     integer s_wsfe(cilist *), do_fio(integer *, char *, ftnlen), e_wsfe(void);
 
     /* Local variables */
-    extern doublereal rcor_(real *, real *, integer *, integer *, integer *), 
-	    rprd_(real *, real *, integer *, integer *, integer *), rcov_(
-	    real *, real *, integer *, integer *, integer *);
+    extern real rcor_(real *, real *, integer *, integer *, integer *), rprd_(
+	    real *, real *, integer *, integer *, integer *), rcov_(real *, 
+	    real *, integer *, integer *, integer *);
 
     /* Fortran I/O blocks */
     static cilist io___3 = { 0, 6, 0, "(A,8F8.1)", 0 };
