@@ -1,4 +1,4 @@
-/*  -- translated by f2c (version 20050501).
+/*  -- translated by f2c (version 20160102).
    You must link the resulting object file with libf2c:
 	on Microsoft Windows system, link with libf2c.lib;
 	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
@@ -35,14 +35,14 @@ static integer c__131 = 131;
 static integer c__24 = 24;
 
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Main program */ int MAIN__(void)
 {
     /* System generated locals */
     address a__1[2];
     integer i__1[2];
-    char ch__1[1];
+    char ch__1[3];
 
     /* Builtin functions */
     integer s_wsle(cilist *), do_lio(integer *, integer *, char *, ftnlen), 
@@ -53,10 +53,10 @@ static integer c__24 = 24;
     static integer n;
     static real r__, x[51], y[51];
     static integer iws;
-    extern /* Character */ VOID csgi_(char *, ftnlen, integer *);
     extern real rave_(real *, integer *, integer *);
     static real yave;
     static char cttl[32];
+    extern /* Character */ VOID usgi_(char *, ftnlen, integer *);
     extern /* Subroutine */ int grcls_(void), grfrm_(void), gropn_(integer *),
 	     sgplu_(integer *, real *, real *), sgiset_(char *, integer *, 
 	    ftnlen), sgspli_(integer *), grswnd_(real *, real *, real *, real 
@@ -109,8 +109,8 @@ static integer c__24 = 24;
     uyaxdv_("L", &c_b37, &c_b38, (ftnlen)1);
     uyaxdv_("R", &c_b37, &c_b38, (ftnlen)1);
 /* Writing concatenation */
-    csgi_(ch__1, (ftnlen)1, &c__131);
-    i__1[0] = 1, a__1[0] = ch__1;
+    usgi_(ch__1, (ftnlen)3, &c__131);
+    i__1[0] = 3, a__1[0] = ch__1;
     i__1[1] = 5, a__1[1] = "T [K]";
     s_cat(cttl, a__1, i__1, &c__2, (ftnlen)32);
     uysttl_("L", cttl, &c_b35, (ftnlen)1, (ftnlen)32);
