@@ -1,6 +1,13 @@
-/* src/env2/dclfont/dclfont.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20160102).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
 #include "libtinyf2c.h"
@@ -21,13 +28,13 @@ static integer c__3 = 3;
 static real c_b40 = .01f;
 
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Main program */ int MAIN__(void)
 {
     /* System generated locals */
     real r__1, r__2;
-    char ch__1[1];
+    char ch__1[3];
 
     /* Builtin functions */
     /* Subroutine */ int s_copy(char *, char *, ftnlen, ftnlen);
@@ -38,8 +45,8 @@ static real c_b40 = .01f;
     static integer i__;
     static char ch[3];
     static real ux, uy;
-    extern /* Character */ VOID csgi_(char *, ftnlen, integer *);
     static char cttl[16];
+    extern /* Character */ VOID usgi_(char *, ftnlen, integer *);
     extern /* Subroutine */ int chngi_(char *, char *, integer *, char *, 
 	    ftnlen, ftnlen, ftnlen), sgcls_(void), sgfrm_(void);
     static integer ifont;
@@ -85,8 +92,8 @@ static real c_b40 = .01f;
     for (i__ = 0; i__ <= 255; ++i__) {
 	ux = i__ / 16 + .5f;
 	uy = 16 - i__ % 16 - .5f;
-	csgi_(ch__1, (ftnlen)1, &i__);
-	sgtxzu_(&ux, &uy, ch__1, &c_b34, &c__0, &c__0, &c__3, (ftnlen)1);
+	usgi_(ch__1, (ftnlen)3, &i__);
+	sgtxzu_(&ux, &uy, ch__1, &c_b34, &c__0, &c__0, &c__3, (ftnlen)3);
 	ux += .48f;
 	uy += .38f;
 	s_wsfi(&io___7);
