@@ -1,6 +1,13 @@
-/* src/grph1/scpack/scsprj.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20160102).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
 #include "libtinyf2c.h"
@@ -9,9 +16,10 @@
 
 static integer c__0 = 0;
 static real c_b17 = 0.f;
+static logical c_false = FALSE_;
 
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int scsprj_(void)
 {
@@ -25,7 +33,7 @@ static real c_b17 = 0.f;
     static real x0, y0, cp, rr, rz, fac, the, phi, psi, sec3;
     static integer ixc3, iyc3, itr3;
     static logical ldeg;
-    extern doublereal rfpi_(void);
+    extern real rfpi_(void);
     static real xobj, yobj, zobj, xoff, yoff, xeye, yeye, zeye, tilt, angle;
     static integer iwtrf;
     static real rxmin, rymin, rxmax, rymax, wxmin, wymin, wxmax, wymax;
@@ -36,8 +44,10 @@ static real c_b17 = 0.f;
 	    msgdmp_(char *, char *, char *, ftnlen, ftnlen, ftnlen), scqeye_(
 	    real *, real *, real *), sgrget_(char *, real *, ftnlen);
     static logical lprjct;
-    extern /* Subroutine */ int stqwtr_(real *, real *, real *, real *, real *
-	    , real *, real *, real *, integer *);
+    extern /* Subroutine */ int swlget_(char *, logical *, ftnlen), swlset_(
+	    char *, logical *, ftnlen), stqwtr_(real *, real *, real *, real *
+	    , real *, real *, real *, real *, integer *);
+    static logical lsysfnt;
 
     scqobj_(&xobj, &yobj, &zobj);
     scqeye_(&xeye, &yeye, &zeye);
@@ -75,7 +85,7 @@ static real c_b17 = 0.f;
 	msgdmp_("E", "SCSPRJ", "ANGLE MUST NOT BE ZERO.", (ftnlen)1, (ftnlen)
 		6, (ftnlen)23);
     } else {
-	fac = (r__1 = .5f / (rr * sin(cp * angle / 2.f)), dabs(r__1));
+	fac = (r__1 = .5f / (rr * sin(cp * angle / 2.f)), abs(r__1));
     }
     if (angle <= 0.f) {
 	rr = -rr;
@@ -91,6 +101,14 @@ static real c_b17 = 0.f;
     } else {
 	stspr2_(&c__0, &c__0, &c_b17);
     }
+    swlget_("LSYSFNT", &lsysfnt, (ftnlen)7);
+    if (lsysfnt) {
+	msgdmp_("W", "SCSPRJ", "SYSTEM FONT IS NOT SUPPORTED IN SCPACK.", (
+		ftnlen)1, (ftnlen)6, (ftnlen)39);
+	msgdmp_("W", "SCSPRJ", "NOTE : LSYSFNT IS SET TO FALSE.", (ftnlen)1, (
+		ftnlen)6, (ftnlen)31);
+	swlset_("LSYSFNT", &c_false, (ftnlen)7);
+    }
     return 0;
 } /* scsprj_ */
 
