@@ -1,6 +1,13 @@
-/* src/grph1/sgpack/sgiqnp.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20160102).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
 #include "libtinyf2c.h"
@@ -8,25 +15,26 @@
 /* Table of constant values */
 
 static integer c__3 = 3;
-static integer c__22 = 22;
+static integer c__24 = 24;
 
 /* ----------------------------------------------------------------------- */
 /*     INTEGER PARAMATER CONTROL */
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int sgiqnp_0_(int n__, integer *ncp, char *cp, integer *idx, 
 	integer *ipara, integer *in, ftnlen cp_len)
 {
     /* Initialized data */
 
-    static char cparas[8*22] = "IRMODE  " "MOVE    " "NBITS   " "ISUP    " 
+    static char cparas[8*24] = "IRMODE  " "MOVE    " "NBITS   " "ISUP    " 
 	    "ISUB    " "IRST    " "NPMSKIP " "IFONT   " "ICLRMAP " "IROT    " 
-	    "INDEXC  " "NBUFF   " "IATONE  " "IWS     " "ITR     " "NFRAME  " 
-	    "NPAGE   " "NLEVEL  " "INDEX   " "ITR3    " "IXC3    " "IYC3    ";
-    static integer ix[22] = { 0,1,16,124,95,34,1,1,1,0,0,200,999,1,1,0,0,0,1,
-	    1,1,2 };
-    static char cparal[40*22] = "BOUNDARY_DIRECTION                      " 
+	    "INDEXC  " "NBUFF   " "IATONE  " "IWS     " "ITR     " "IBGCLI  " 
+	    "NFRAME  " "NPAGE   " "NLEVEL  " "INDEX   " "ITR3    " "IXC3    " 
+	    "IYC3    " "IFCIDX  ";
+    static integer ix[24] = { 0,1,16,124,95,34,1,1,1,0,0,200,999,0,1,999,0,0,
+	    0,1,1,1,2,998 };
+    static char cparal[40*24] = "BOUNDARY_DIRECTION                      " 
 	    "LINE_RESUME_MODE                        " "PATTERN_BIT_LENGTH  "
 	    "                    " "BEGIN_SUPERSCRIPT                       " 
 	    "BEGIN_SUBSCRIPT                         " "END_SCRIPT          "
@@ -36,11 +44,13 @@ static integer c__22 = 22;
 	    "LABEL_CHAR_INDEX                        " "LINE_BUFFERING_LENGT"
 	    "H                   " "ARROWHEAD_SHADE_PATTERN                 " 
 	    "++++IWS                                 " "++++ITR             "
-	    "                    " "****NFRAME                              " 
-	    "****NPAGE                               " "****NLEVEL          "
-	    "                    " "CORNERMARK_INDEX                        " 
-	    "++++ITR3                                " "++++IXC3            "
-	    "                    " "++++IYC3                                ";
+	    "                    " "BACKGROUND_COLOR_INDEX                  " 
+	    "****NFRAME                              " "****NPAGE           "
+	    "                    " "****NLEVEL                              " 
+	    "CORNERMARK_INDEX                        " "++++ITR3            "
+	    "                    " "++++IXC3                                " 
+	    "++++IYC3                                " "FULLCOLOR_INDEX     "
+	    "                    ";
     static logical lfirst = TRUE_;
 
     /* System generated locals */
@@ -71,12 +81,12 @@ static integer c__22 = 22;
 	}
 
 /*     / LONG  NAME / */
-    *ncp = 22;
+    *ncp = 24;
     return 0;
 /* ----------------------------------------------------------------------- */
 
 L_sgiqid:
-    for (n = 1; n <= 22; ++n) {
+    for (n = 1; n <= 24; ++n) {
 	if (lchreq_(cp, cparas + (n - 1 << 3), cp_len, (ftnlen)8) || lchreq_(
 		cp, cparal + (n - 1) * 40, cp_len, (ftnlen)40)) {
 	    *idx = n;
@@ -94,7 +104,7 @@ L_sgiqid:
 /* ----------------------------------------------------------------------- */
 
 L_sgiqcp:
-    if (1 <= *idx && *idx <= 22) {
+    if (1 <= *idx && *idx <= 24) {
 	s_copy(cp, cparas + (*idx - 1 << 3), cp_len, (ftnlen)8);
     } else {
 	msgdmp_("E", "SGIQCP", "IDX IS OUT OF RANGE.", (ftnlen)1, (ftnlen)6, (
@@ -104,7 +114,7 @@ L_sgiqcp:
 /* ----------------------------------------------------------------------- */
 
 L_sgiqcl:
-    if (1 <= *idx && *idx <= 22) {
+    if (1 <= *idx && *idx <= 24) {
 	s_copy(cp, cparal + (*idx - 1) * 40, cp_len, (ftnlen)40);
     } else {
 	msgdmp_("E", "SGIQCL", "IDX IS OUT OF RANGE.", (ftnlen)1, (ftnlen)6, (
@@ -115,11 +125,11 @@ L_sgiqcl:
 
 L_sgiqvl:
     if (lfirst) {
-	rtiget_("SG", cparas, ix, &c__22, (ftnlen)2, (ftnlen)8);
-	rliget_(cparal, ix, &c__22, (ftnlen)40);
+	rtiget_("SG", cparas, ix, &c__24, (ftnlen)2, (ftnlen)8);
+	rliget_(cparal, ix, &c__24, (ftnlen)40);
 	lfirst = FALSE_;
     }
-    if (1 <= *idx && *idx <= 22) {
+    if (1 <= *idx && *idx <= 24) {
 	*ipara = ix[*idx - 1];
     } else {
 	msgdmp_("E", "SGIQVL", "IDX IS OUT OF RANGE.", (ftnlen)1, (ftnlen)6, (
@@ -130,11 +140,11 @@ L_sgiqvl:
 
 L_sgisvl:
     if (lfirst) {
-	rtiget_("SG", cparas, ix, &c__22, (ftnlen)2, (ftnlen)8);
-	rliget_(cparal, ix, &c__22, (ftnlen)40);
+	rtiget_("SG", cparas, ix, &c__24, (ftnlen)2, (ftnlen)8);
+	rliget_(cparal, ix, &c__24, (ftnlen)40);
 	lfirst = FALSE_;
     }
-    if (1 <= *idx && *idx <= 22) {
+    if (1 <= *idx && *idx <= 24) {
 	ix[*idx - 1] = *ipara;
     } else {
 	msgdmp_("E", "SGISVL", "IDX IS OUT OF RANGE.", (ftnlen)1, (ftnlen)6, (
@@ -144,7 +154,7 @@ L_sgisvl:
 /* ----------------------------------------------------------------------- */
 
 L_sgiqin:
-    for (n = 1; n <= 22; ++n) {
+    for (n = 1; n <= 24; ++n) {
 	if (lchreq_(cp, cparas + (n - 1 << 3), cp_len, (ftnlen)8) || lchreq_(
 		cp, cparal + (n - 1) * 40, cp_len, (ftnlen)40)) {
 	    *in = n;
