@@ -1,4 +1,4 @@
-/*  -- translated by f2c (version 20100827).
+/*  -- translated by f2c (version 20160102).
    You must link the resulting object file with libf2c:
 	on Microsoft Windows system, link with libf2c.lib;
 	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
@@ -26,12 +26,14 @@ static integer c__3 = 3;
 {
     /* Initialized data */
 
-    static char cparas[8*21] = "MAXWNU  " "IWS     " "IPOSX   " "IPOSY   " 
+    static char cparas[8*27] = "MAXWNU  " "IWS     " "IPOSX   " "IPOSY   " 
 	    "IWIDTH  " "IHEIGHT " "LWAIT   " "LWAIT0  " "LWAIT1  " "LKEY    " 
 	    "LDUMP   " "LALT    " "LCOLOR  " "LSEP    " "LPRINT  " "LWND    " 
-	    "MODE    " "NLNSIZE " "ICLRMAP " "LFGBG   " "LSYSFNT ";
-    static integer itype[21] = { 1,0,1,1,1,1,2,2,2,2,2,2,2,2,2,2,1,1,1,2,2 };
-    static char cparal[40*21] = "****MAXWNU                              " 
+	    "MODE    " "NLNSIZE " "ICLRMAP " "LFGBG   " "LSYSFNT " "IDMPDGT " 
+	    "MAXFNU  " "IFL     " "IBGPAGE " "LCMCH   " "LSTDOT  ";
+    static integer itype[27] = { 1,0,1,1,1,1,2,2,2,2,2,2,2,2,2,2,1,1,1,2,2,1,
+	    1,1,1,2,2 };
+    static char cparal[40*27] = "****MAXWNU                              " 
 	    "****IWS                                 " "WINDOW_X_POS        "
 	    "                    " "WINDOW_Y_POS                            " 
 	    "WINDOW_WIDTH                            " "WINDOW_HEIGHT       "
@@ -45,6 +47,10 @@ static integer c__3 = 3;
 	    "****MODE                                " "****NLNSIZE         "
 	    "                    " "COLORMAP_NUMBER                         " 
 	    "****LFGBG                               " "USE_SYSTEM_FONT     "
+	    "                    " "DMPFILE_DIGITS                          " 
+	    "****MAXFNU                              " "****IFL             "
+	    "                    " "BEGIN PAGE                              " 
+	    "CMAP_CHANGABLE                          " "PNG_STDOUT          "
 	    "                    ";
 
     /* System generated locals */
@@ -79,12 +85,12 @@ static integer c__3 = 3;
 	}
 
 /*     / LONG NAME / */
-    *ncp = 21;
+    *ncp = 27;
     return 0;
 /* ----------------------------------------------------------------------- */
 
 L_swpqid:
-    for (n = 1; n <= 21; ++n) {
+    for (n = 1; n <= 27; ++n) {
 	if (lchreq_(cp, cparas + (n - 1 << 3), cp_len, (ftnlen)8) || lchreq_(
 		cp, cparal + (n - 1) * 40, cp_len, (ftnlen)40)) {
 	    *idx = n;
@@ -102,7 +108,7 @@ L_swpqid:
 /* ----------------------------------------------------------------------- */
 
 L_swpqcp:
-    if (1 <= *idx && *idx <= 21) {
+    if (1 <= *idx && *idx <= 27) {
 	s_copy(cp, cparas + (*idx - 1 << 3), cp_len, (ftnlen)8);
     } else {
 	msgdmp_("E", "SWPQCP", "IDX IS OUT OF RANGE.", (ftnlen)1, (ftnlen)6, (
@@ -112,7 +118,7 @@ L_swpqcp:
 /* ----------------------------------------------------------------------- */
 
 L_swpqcl:
-    if (1 <= *idx && *idx <= 21) {
+    if (1 <= *idx && *idx <= 27) {
 	s_copy(cp, cparal + (*idx - 1) * 40, cp_len, (ftnlen)40);
     } else {
 	msgdmp_("E", "SWPQCL", "IDX IS OUT OF RANGE.", (ftnlen)1, (ftnlen)6, (
@@ -122,7 +128,7 @@ L_swpqcl:
 /* ----------------------------------------------------------------------- */
 
 L_swpqit:
-    if (1 <= *idx && *idx <= 21) {
+    if (1 <= *idx && *idx <= 27) {
 	*itp = itype[*idx - 1];
     } else {
 	msgdmp_("E", "SWPQIT", "IDX IS OUT OF RANGE.", (ftnlen)1, (ftnlen)6, (
@@ -132,7 +138,7 @@ L_swpqit:
 /* ----------------------------------------------------------------------- */
 
 L_swpqvl:
-    if (1 <= *idx && *idx <= 21) {
+    if (1 <= *idx && *idx <= 27) {
 	if (itype[*idx - 1] == 1) {
 	    swiqid_(cparas + (*idx - 1 << 3), &id, (ftnlen)8);
 	    swiqvl_(&id, ipara);
@@ -151,7 +157,7 @@ L_swpqvl:
 /* ----------------------------------------------------------------------- */
 
 L_swpsvl:
-    if (1 <= *idx && *idx <= 21) {
+    if (1 <= *idx && *idx <= 27) {
 	if (itype[*idx - 1] == 1) {
 	    swiqid_(cparas + (*idx - 1 << 3), &id, (ftnlen)8);
 	    swisvl_(&id, ipara);
@@ -170,7 +176,7 @@ L_swpsvl:
 /* ----------------------------------------------------------------------- */
 
 L_swpqin:
-    for (n = 1; n <= 21; ++n) {
+    for (n = 1; n <= 27; ++n) {
 	if (lchreq_(cp, cparas + (n - 1 << 3), cp_len, (ftnlen)8) || lchreq_(
 		cp, cparal + (n - 1) * 40, cp_len, (ftnlen)40)) {
 	    *in = n;
