@@ -1,6 +1,13 @@
-/* src/grph1/szpack/szlazv.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20160102).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
 #include "libtinyf2c.h"
@@ -17,7 +24,7 @@ struct {
 #define szbla1_1 szbla1_
 
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int szlazv_(real *vx1, real *vy1, real *vx2, real *vy2)
 {
@@ -30,7 +37,7 @@ struct {
     /* Local variables */
     static real r__, ar, pi, xe, ye, xa1, ya1, xa2, ya2;
     extern /* Subroutine */ int cr2c_(real *, real *, real *, real *, real *);
-    extern doublereal rfpi_(void);
+    extern real rfpi_(void);
     extern /* Subroutine */ int szcllv_(void), szcltv_(void), szpllv_(real *, 
 	    real *), szoplv_(void), szmvlv_(real *, real *), szoptv_(void), 
 	    szsttv_(real *, real *);
