@@ -1,6 +1,13 @@
-/* src/grph1/szpack/sztxop.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20160102).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
 #include "libtinyf2c.h"
@@ -33,7 +40,7 @@ struct {
 static integer c__1 = 1;
 
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int sztxop_0_(int n__, real *rsize, integer *irota, integer *
 	icent, integer *index)
@@ -48,11 +55,12 @@ static integer c__1 = 1;
 
     /* Local variables */
     static integer iws;
-    extern doublereal rd2r_(real *);
+    extern real rd2r_(real *);
     static char cobj[80];
     static integer isub, isup, irst;
     extern /* Subroutine */ int cdblk_(char *, ftnlen);
     static real theta;
+    static integer ifont;
     extern /* Subroutine */ int sgiget_(char *, integer *, ftnlen), sglget_(
 	    char *, logical *, ftnlen), sgrget_(char *, real *, ftnlen);
     static integer indexz;
@@ -60,14 +68,14 @@ static integer c__1 = 1;
 	    szsidx_(integer *), swoopn_(char *, char *, ftnlen, ftnlen);
 
     /* Fortran I/O blocks */
-    static icilist io___8 = { 0, cobj, 0, "(F8.5,5I8)", 80, 1 };
+    static icilist io___9 = { 0, cobj, 0, "(F8.5,5I8)", 80, 1 };
 
 
-/*     CALL SGIGET('IFONT',IFONT) */
     switch(n__) {
 	case 1: goto L_sztxcl;
 	}
 
+    sgiget_("IFONT", &ifont, (ftnlen)5);
     szbtx1_1.qsize = *rsize / 24.f;
     r__1 = (real) (*irota);
     theta = rd2r_(&r__1);
@@ -87,14 +95,15 @@ static integer c__1 = 1;
     szbtx2_1.jrst = irst + 1;
     szqidx_(&indexz);
     szsidx_(index);
-/*     WRITE(COBJ,'(F8.5,5I8)') RSIZE,IROTA,ICENT,INDEX,IFONT,IWS */
-    s_wsfi(&io___8);
+    s_wsfi(&io___9);
     do_fio(&c__1, (char *)&(*rsize), (ftnlen)sizeof(real));
     do_fio(&c__1, (char *)&(*irota), (ftnlen)sizeof(integer));
     do_fio(&c__1, (char *)&(*icent), (ftnlen)sizeof(integer));
     do_fio(&c__1, (char *)&(*index), (ftnlen)sizeof(integer));
+    do_fio(&c__1, (char *)&ifont, (ftnlen)sizeof(integer));
     do_fio(&c__1, (char *)&iws, (ftnlen)sizeof(integer));
     e_wsfi();
+/*     WRITE(COBJ,'(F8.5,5I8)') RSIZE,IROTA,ICENT,INDEX,IWS */
     cdblk_(cobj, (ftnlen)80);
     swoopn_("SZTX", cobj, (ftnlen)4, (ftnlen)80);
     return 0;
