@@ -1,4 +1,4 @@
-/*  -- translated by f2c (version 20050501).
+/*  -- translated by f2c (version 20160102).
    You must link the resulting object file with libf2c:
 	on Microsoft Windows system, link with libf2c.lib;
 	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
@@ -22,7 +22,7 @@ static logical c_false = FALSE_;
 /* ----------------------------------------------------------------------- */
 /*     UCYADY : PLOT DATE AXIS */
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int ucyady_(char *cside, integer *jd0, integer *nd, ftnlen 
 	cside_len)
@@ -93,6 +93,10 @@ static logical c_false = FALSE_;
 	iml = ndmon_(&iyi, &moi);
 	if (idi < iml - id / 2 && idi % id == 0 || idi == iml) {
 	    ++nn;
+	    if (nn > 100) {
+		msgdmp_("E", "UCYADY", "WORKING AREA IS NOT ENOUGH.", (ftnlen)
+			1, (ftnlen)6, (ftnlen)27);
+	    }
 	    uy[nn - 1] = (real) i__;
 	    ici__1.icierr = 0;
 	    ici__1.icirnum = 1;
@@ -110,9 +114,6 @@ static logical c_false = FALSE_;
 	msgdmp_("W", "UCYADY", "THERE IS NO TICKMARK / LABEL.", (ftnlen)1, (
 		ftnlen)6, (ftnlen)29);
 	return 0;
-    } else if (nn > 100) {
-	msgdmp_("E", "UCYADY", "WORKING AREA IS NOT ENOUGH.", (ftnlen)1, (
-		ftnlen)6, (ftnlen)27);
     }
 /* Writing concatenation */
     i__2[0] = 6, a__1[0] = "ICENTY";
