@@ -1,4 +1,4 @@
-/*  -- translated by f2c (version 20100827).
+/*  -- translated by f2c (version 20160102).
    You must link the resulting object file with libf2c:
 	on Microsoft Windows system, link with libf2c.lib;
 	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
@@ -23,7 +23,7 @@ struct {
 #define ueblk1_1 ueblk1_
 
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int uetonf_(real *z__, integer *mx, integer *nx, integer *ny)
 {
@@ -38,45 +38,48 @@ struct {
     static integer ix1, iy1, ix2, iy2, ix3, iy3, ix4, iy4;
     static real wx1, wy1, wx2, wy2, wx3, wy3, wx4, wy4;
     static integer itr;
-    static real uyn, uyx;
+    static real uyn, tux, tuy, uyx;
     static logical limc;
+    static real tuxz, tuyz;
     static integer image[4000], istat, ixmin, iymin;
     static logical lmiss;
     static integer ixmax, iymax;
-    static real rmiss, vxmin, vymin, vxmax, vymax;
+    static real rmiss, txmin, tymin, txmax, tymax, vxmin, vxmax, vymin, vymax;
     extern /* Subroutine */ int stfpr2_(real *, real *, real *, real *), 
 	    stipr2_(real *, real *, real *, real *);
     static integer ibgcli, iundef;
     extern /* Subroutine */ int gliget_(char *, integer *, ftnlen);
     static integer ihight;
-    extern /* Subroutine */ int gllget_(char *, logical *, ftnlen), sgiget_(
-	    char *, integer *, ftnlen);
+    extern /* Subroutine */ int gllget_(char *, logical *, ftnlen);
     static real rundef;
-    extern /* Subroutine */ int glrget_(char *, real *, ftnlen), msgdmp_(char 
-	    *, char *, char *, ftnlen, ftnlen, ftnlen);
+    extern /* Subroutine */ int glrget_(char *, real *, ftnlen), stirad_(real 
+	    *, real *, real *, real *), msgdmp_(char *, char *, char *, 
+	    ftnlen, ftnlen, ftnlen);
     static integer iwidth;
     extern /* Subroutine */ int uezchk_(real *, integer *, integer *, integer 
 	    *, char *, integer *, ftnlen), sgrget_(char *, real *, ftnlen), 
 	    swidat_(integer *, integer *);
+    static logical lexten;
+    extern /* Subroutine */ int swqimc_(logical *);
     extern integer iueton_(real *);
-    extern /* Subroutine */ int swqimc_(logical *), uwdflt_(integer *, 
-	    integer *), swicls_(void), swfint_(real *, real *, integer *, 
-	    integer *), stitrf_(real *, real *, real *, real *), swiint_(
-	    integer *, integer *, real *, real *), sgqtrn_(integer *), 
-	    swiopn_(integer *, integer *, integer *, integer *, real *, real *
-	    , real *, real *, real *, real *, real *, real *), sgqvpt_(real *,
-	     real *, real *, real *), uwqgxi_(real *, integer *, real *), 
-	    uwqgyi_(real *, integer *, real *), stfwtr_(real *, real *, real *
-	    , real *), stiwtr_(real *, real *, real *, real *);
+    extern /* Subroutine */ int uwdflt_(integer *, integer *), swicls_(void), 
+	    swfint_(real *, real *, integer *, integer *), stitrf_(real *, 
+	    real *, real *, real *), swiint_(integer *, integer *, real *, 
+	    real *), sgqtrn_(integer *), swiopn_(integer *, integer *, 
+	    integer *, integer *, real *, real *, real *, real *, real *, 
+	    real *, real *, real *), stitrn_(real *, real *, real *, real *), 
+	    sgqvpt_(real *, real *, real *, real *), uwqgxi_(real *, integer *
+	    , real *), uwqgyi_(real *, integer *, real *), stfwtr_(real *, 
+	    real *, real *, real *), stiwtr_(real *, real *, real *, real *), 
+	    sgqtxy_(real *, real *, real *, real *);
 
+/*     / CHECK IMAGE CAPABILITY / */
     /* Parameter adjustments */
     z_dim1 = *mx;
     z_offset = 1 + z_dim1;
     z__ -= z_offset;
 
     /* Function Body */
-    sgiget_("IBGCLI", &ibgcli, (ftnlen)6);
-/*     / CHECK IMAGE CAPABILITY / */
     swqimc_(&limc);
     if (! limc) {
 	msgdmp_("E", "UETONF", "NO IMAGE CAPABILITY.", (ftnlen)1, (ftnlen)6, (
@@ -125,6 +128,7 @@ struct {
     swiopn_(&ixmin, &iymin, &iwidth, &ihight, &wx1, &wy1, &wx2, &wy2, &wx3, &
 	    wy3, &wx4, &wy4);
 /*     / LOOP FOR EACH PIXEL / */
+    sgqtxy_(&txmin, &txmax, &tymin, &tymax);
     i__1 = ihight;
     for (j = 1; j <= i__1; ++j) {
 	i__2 = iwidth;
@@ -149,20 +153,31 @@ struct {
 		    if (uyx < uyn + 360) {
 			uyx = uyn + 360;
 		    }
-L360:
-		    if (uy < uyn) {
-			uy += 360;
-		    }
-		    if (uy >= uyx) {
-			uy += -360;
-		    }
-		    if (uy < uyn || uy >= uyx) {
-			goto L360;
-		    }
 		}
 		uwqgxi_(&ux, &ix, &fx);
 		uwqgyi_(&uy, &iy, &fy);
-		if (ix == iundef || iy == iundef) {
+		stitrn_(&vx, &vy, &tuxz, &tuyz);
+		stirad_(&tuxz, &tuyz, &tux, &tuy);
+/*          TUX=RMOD(UX,360.)-180. */
+		if (txmin <= txmax) {
+		    if (tux >= txmin && tux <= txmax) {
+			lexten = FALSE_;
+		    } else {
+			lexten = TRUE_;
+		    }
+		} else {
+		    if (tux >= txmin || tux <= txmax) {
+			lexten = FALSE_;
+		    } else {
+			lexten = TRUE_;
+		    }
+		}
+		if (tuy >= tymax || tuy <= tymin) {
+		    lexten = TRUE_;
+		}
+		if (lexten && itr >= 5) {
+		    image[i__ - 1] = 0;
+		} else if (ix == iundef || iy == iundef) {
 		    image[i__ - 1] = 0;
 		} else {
 		    if (lmiss && (z__[ix + iy * z_dim1] == rmiss || z__[ix + 
