@@ -1,4 +1,4 @@
-/*  -- translated by f2c (version 20100827).
+/*  -- translated by f2c (version 20160102).
    You must link the resulting object file with libf2c:
 	on Microsoft Windows system, link with libf2c.lib;
 	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
@@ -25,6 +25,26 @@ static integer c__1 = 1;
     /* Initialized data */
 
     static integer nlev = 7;
+    static real rcmax = 999.f;
+    static real rsmin = 999.f;
+    static real rsmax = 999.f;
+    static real sd[256] = { -.2f,-.2f,.2f,.2f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,
+	    0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,
+	    0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,
+	    0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,
+	    0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,
+	    0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,
+	    0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,
+	    0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,
+	    0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,
+	    0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,
+	    0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,
+	    0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,
+	    0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,
+	    0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,
+	    0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,
+	    0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,
+	    0.f,0.f,0.f,0.f };
     static real rs0[256] = { 0.f,.5f,.5f,1.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,
 	    0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,
 	    0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,
@@ -89,23 +109,7 @@ static integer c__1 = 1;
 	    0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,
 	    0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,
 	    0.f,0.f,0.f,0.f,0.f,0.f,0.f };
-    static real sd[256] = { -.2f,-.2f,.2f,.2f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,
-	    0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,
-	    0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,
-	    0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,
-	    0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,
-	    0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,
-	    0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,
-	    0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,
-	    0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,
-	    0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,
-	    0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,
-	    0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,
-	    0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,
-	    0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,
-	    0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,
-	    0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,0.f,
-	    0.f,0.f,0.f,0.f };
+    static real rcmin = 999.f;
 
     /* System generated locals */
     address a__1[2];
@@ -133,9 +137,8 @@ static integer c__1 = 1;
     static integer iclr;
     static real rmin, rmax;
     static integer iost;
-    static real range, rcmin, rcmax;
+    static real range;
     static char cdsnx[1024];
-    static real rsmin, rsmax;
     static logical lshade;
     extern /* Subroutine */ int uifpac_(integer *, integer *, integer *, 
 	    integer *), uiipac_(integer *, integer *, integer *, integer *);
@@ -172,10 +175,12 @@ static integer c__1 = 1;
 	case 1: goto L_uicini;
 	case 2: goto L_uiscrg;
 	case 3: goto L_uismrg;
-	case 4: goto L_uiscsq;
-	case 5: goto L_uiscfl;
-	case 6: goto L_uismsq;
-	case 7: goto L_uismfl;
+	case 4: goto L_uiqcrg;
+	case 5: goto L_uiqmrg;
+	case 6: goto L_uiscsq;
+	case 7: goto L_uiscfl;
+	case 8: goto L_uismsq;
+	case 9: goto L_uismfl;
 	}
 
     if (lcycle) {
@@ -289,6 +294,18 @@ L_uismrg:
     return 0;
 /* ----------------------------------------------------------------------- */
 
+L_uiqcrg:
+    *zmin = rcmin;
+    *zmax = rcmax;
+    return 0;
+/* ----------------------------------------------------------------------- */
+
+L_uiqmrg:
+    *zmin = rsmin;
+    *zmax = rsmax;
+    return 0;
+/* ----------------------------------------------------------------------- */
+
 L_uiscsq:
     if (*n > 256) {
 	msgdmp_("M", "UISCSQ", "TOO MANY LEVEL (N).", (ftnlen)1, (ftnlen)6, (
@@ -489,30 +506,44 @@ L100002:
 	    (ftnint)0);
     }
 
+/* Subroutine */ int uiqcrg_(real *zmin, real *zmax)
+{
+    return uicrgb_0_(4, (real *)0, (real *)0, (integer *)0, zmin, zmax, (real 
+	    *)0, (integer *)0, (integer *)0, (char *)0, (real *)0, (real *)0, 
+	    (ftnint)0);
+    }
+
+/* Subroutine */ int uiqmrg_(real *zmin, real *zmax)
+{
+    return uicrgb_0_(5, (real *)0, (real *)0, (integer *)0, zmin, zmax, (real 
+	    *)0, (integer *)0, (integer *)0, (char *)0, (real *)0, (real *)0, 
+	    (ftnint)0);
+    }
+
 /* Subroutine */ int uiscsq_(real *clrlvl, integer *icolor, integer *n)
 {
-    return uicrgb_0_(4, (real *)0, (real *)0, (integer *)0, (real *)0, (real *
+    return uicrgb_0_(6, (real *)0, (real *)0, (integer *)0, (real *)0, (real *
 	    )0, clrlvl, icolor, n, (char *)0, (real *)0, (real *)0, (ftnint)0)
 	    ;
     }
 
 /* Subroutine */ int uiscfl_(char *cdsn, ftnlen cdsn_len)
 {
-    return uicrgb_0_(5, (real *)0, (real *)0, (integer *)0, (real *)0, (real *
+    return uicrgb_0_(7, (real *)0, (real *)0, (integer *)0, (real *)0, (real *
 	    )0, (real *)0, (integer *)0, (integer *)0, cdsn, (real *)0, (real 
 	    *)0, cdsn_len);
     }
 
 /* Subroutine */ int uismsq_(real *shdlvl, real *shade, integer *n)
 {
-    return uicrgb_0_(6, (real *)0, (real *)0, (integer *)0, (real *)0, (real *
+    return uicrgb_0_(8, (real *)0, (real *)0, (integer *)0, (real *)0, (real *
 	    )0, (real *)0, (integer *)0, n, (char *)0, shdlvl, shade, (ftnint)
 	    0);
     }
 
 /* Subroutine */ int uismfl_(char *cdsn, ftnlen cdsn_len)
 {
-    return uicrgb_0_(7, (real *)0, (real *)0, (integer *)0, (real *)0, (real *
+    return uicrgb_0_(9, (real *)0, (real *)0, (integer *)0, (real *)0, (real *
 	    )0, (real *)0, (integer *)0, (integer *)0, cdsn, (real *)0, (real 
 	    *)0, cdsn_len);
     }
