@@ -1,12 +1,19 @@
-/* src/grph2/umpack/umbndr.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20160102).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
 #include "libtinyf2c.h"
 
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int umbndr_(S_fp func, S_fp ftr, real *xmin, real *xmax, 
 	real *ymin, real *ymax)
@@ -42,16 +49,16 @@
 	(*func)(&uxmax, &y, &x4, &y4);
 /* Computing MAX */
 	r__1 = max(*xmax,x1), r__1 = max(r__1,x2), r__1 = max(r__1,x3);
-	*xmax = dmax(r__1,x4);
+	*xmax = max(r__1,x4);
 /* Computing MIN */
 	r__1 = min(*xmin,x1), r__1 = min(r__1,x2), r__1 = min(r__1,x3);
-	*xmin = dmin(r__1,x4);
+	*xmin = min(r__1,x4);
 /* Computing MAX */
 	r__1 = max(*ymax,y1), r__1 = max(r__1,y2), r__1 = max(r__1,y3);
-	*ymax = dmax(r__1,y4);
+	*ymax = max(r__1,y4);
 /* Computing MIN */
 	r__1 = min(*ymin,y1), r__1 = min(r__1,y2), r__1 = min(r__1,y3);
-	*ymin = dmin(r__1,y4);
+	*ymin = min(r__1,y4);
 /* L10: */
     }
     return 0;
