@@ -1,6 +1,13 @@
-/* src/grph2/umpack/umspct.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20160102).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
 #include "libtinyf2c.h"
@@ -21,7 +28,7 @@ struct {
 /* ----------------------------------------------------------------------- */
 /*     UMSPCT : CONTACT POINT MODE */
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int umspct_(void)
 {
@@ -55,7 +62,7 @@ struct {
     yctctz = yctct / umwk1_1.cpr;
     rotz = rot / umwk1_1.cpr;
 /* --------------------- CYLINDRICAL PROJECTION -------------------------- */
-    if (10 <= umwk1_1.itr && umwk1_1.itr <= 15) {
+    if (10 <= umwk1_1.itr && umwk1_1.itr <= 19) {
 	if (rotz != 0.f) {
 	    a = umwk1_1.pi / 2.f - yctctz;
 	    c__ = acos(sin(a) * cos(rotz));
@@ -67,7 +74,7 @@ struct {
 	    ply = (umwk1_1.pi / 2.f - c__) * umwk1_1.cpr;
 	    plrot = (umwk1_1.pi - alph) * umwk1_1.cpr;
 	} else {
-	    ply = umwk1_1.pi / 2.f * umwk1_1.cpr - dabs(yctct);
+	    ply = umwk1_1.pi / 2.f * umwk1_1.cpr - abs(yctct);
 	    if (yctct <= 0.f) {
 		plx = xctct;
 		plrot = 0.f;
@@ -77,20 +84,20 @@ struct {
 	    }
 	}
 /* ----------------------- CONICAL PROJECTION ---------------------------- */
-    } else if (20 <= umwk1_1.itr && umwk1_1.itr <= 23) {
+    } else if (20 <= umwk1_1.itr && umwk1_1.itr <= 24) {
 	sgrget_("STLAT1", &st1, (ftnlen)6);
 	if (umwk1_1.itr == 22) {
 	    sgrget_("STLAT2", &st2, (ftnlen)6);
 	    if (st1 == umwk1_1.rundef) {
 /* Computing MAX */
 		r__1 = yctct - umwk1_1.cpd * 5.f, r__2 = -umwk1_1.pi / 2.f;
-		st1 = dmax(r__1,r__2);
+		st1 = max(r__1,r__2);
 		sgrset_("STLAT1", &st1, (ftnlen)6);
 	    }
 	    if (st2 == umwk1_1.rundef) {
 /* Computing MIN */
 		r__1 = yctct + umwk1_1.cpd * 5.f, r__2 = umwk1_1.pi / 2.f;
-		st2 = dmin(r__1,r__2);
+		st2 = min(r__1,r__2);
 		sgrset_("STLAT2", &st2, (ftnlen)6);
 	    }
 	    yc = (st1 + st2) / 2.f / umwk1_1.cpr;
@@ -122,7 +129,7 @@ struct {
 	    plrot = umwk1_1.cpd * 0.f;
 	}
 /* ---------------------- AZIMUTHAL PROJECTION --------------------------- */
-    } else if (30 <= umwk1_1.itr && umwk1_1.itr <= 33) {
+    } else if (30 <= umwk1_1.itr && umwk1_1.itr <= 34) {
 	plx = xctct;
 	ply = yctct;
 	plrot = rot;
