@@ -1,4 +1,4 @@
-/*  -- translated by f2c (version 20100827).
+/*  -- translated by f2c (version 20160102).
    You must link the resulting object file with libf2c:
 	on Microsoft Windows system, link with libf2c.lib;
 	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
@@ -16,7 +16,6 @@
 
 static integer c__2 = 2;
 static integer c__4 = 4;
-static doublereal c_b16 = 10.;
 
 /* ----------------------------------------------------------------------- */
 /*     USPACK AUTO SCALING ROUTINE (LOG)                DCL 5.0 95/09/04 */
@@ -37,7 +36,7 @@ static doublereal c_b16 = 10.;
 
     /* Builtin functions */
     /* Subroutine */ int s_cat(char *, char **, integer *, integer *, ftnlen);
-    double pow_di(doublereal *, integer *), r_lg10(real *);
+    double r_lg10(real *);
 
     /* Local variables */
     static char cp[8];
@@ -86,16 +85,16 @@ static doublereal c_b16 = 10.;
     gnle_(&r__1, &bumin, &ipmin);
     gnrset_();
     if (ipmax <= ipmin + 1) {
-	itype = 3;
-	if (ipmax + 1 > mxdgt || 2 - ipmin > mxdgt) {
-	    ufac = pow_di(&c_b16, &ipmin);
-	} else {
-	    ufac = 1.f;
-	}
+	itype = 1;
+/*        IF(IPMAX+1.GT.MXDGT .OR. 2-IPMIN.GT.MXDGT) THEN */
+/*          UFAC = 1.D1**IPMIN */
+/*        ELSE */
+/*        ENDIF */
     } else {
 	itype = 2;
-	ufac = 1.f;
     }
+    ufac = 1.f;
+
 /* Writing concatenation */
     i__1[0] = 1, a__1[0] = caxis;
     i__1[1] = 3, a__1[1] = "FAC";
