@@ -1,4 +1,4 @@
-/*  -- translated by f2c (version 20100827).
+/*  -- translated by f2c (version 20160102).
    You must link the resulting object file with libf2c:
 	on Microsoft Windows system, link with libf2c.lib;
 	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
@@ -75,8 +75,8 @@ static real c_b17 = 3.f;
 		ftnlen)6, (ftnlen)30);
     }
     sgqwnd_(&xmin, &xmax, &ymin, &ymax);
-    xmina = xmin / xfac;
-    xmaxa = xmax / xfac;
+    xmina = xmin * xfac;
+    xmaxa = xmax * xfac;
     sgswnd_(&xmina, &xmaxa, &ymin, &ymax);
     sgstrf_();
 /* ---------------------------- X-AXIS ----------------------------------- */
