@@ -1,6 +1,13 @@
-/* src/grph2/uxpack/uxplbb.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20160102).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
 #include "libtinyf2c.h"
@@ -12,7 +19,7 @@ static logical c_false = FALSE_;
 /* ----------------------------------------------------------------------- */
 /*     UXPLBB : PLOT LABELS ( BETWEEN THE POINTS ) */
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int uxplbb_(real *ux, char *ch, integer *nc, integer *n, 
 	real *upy, real *roffx, real *rsize, integer *irota, integer *icent, 
@@ -72,7 +79,7 @@ static logical c_false = FALSE_;
 	szqtxw_(ch + i__ * ch_len, &lcz, &wxch, &wych, ch_len);
 	stftrf_(&ux[i__], upy, &vpx1, &vpy);
 	stftrf_(&ux[i__ + 1], upy, &vpx2, &vpy);
-	vwx = (r__1 = vpx2 - vpx1, dabs(r__1));
+	vwx = (r__1 = vpx2 - vpx1, abs(r__1));
 	jrota = *irota % 2;
 	if (jrota == 0) {
 	    cwx = *rsize * wxch;
