@@ -1,6 +1,13 @@
-/* src/grph2/uypack/uysaxs.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20160102).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
 #include "libtinyf2c.h"
@@ -13,7 +20,7 @@ static integer c__1 = 1;
 /* ----------------------------------------------------------------------- */
 /*     UYSAXS : OFFSET FOR NEW AXIS */
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int uysaxs_(char *cside, ftnlen cside_len)
 {
@@ -69,11 +76,11 @@ static integer c__1 = 1;
     if (iflag >= 0) {
 /* Computing MAX */
 	r__1 = roffy - rtick;
-	roffy = dmax(r__1,roffy) + rsizec * pad;
+	roffy = max(r__1,roffy) + rsizec * pad;
     } else {
 /* Computing MIN */
 	r__1 = roffy - rtick;
-	roffy = dmin(r__1,roffy) - rsizec * pad;
+	roffy = min(r__1,roffy) - rsizec * pad;
     }
     uysaxz_(cside, &roffy, (ftnlen)1);
     return 0;
