@@ -1,6 +1,13 @@
-/* src/math1/maplib/mpfcoa.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20160102).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
 #include "libtinyf2c.h"
@@ -12,7 +19,7 @@ static real c_b3 = 1.f;
 /* ----------------------------------------------------------------------- */
 /*     MAP PROJECTION (LAMBERT CONICAL 1)               93/02/20 S.SAKAI */
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int mpfcoa_0_(int n__, real *xlon, real *ylat, real *x, real 
 	*y, real *ylat0)
@@ -23,9 +30,9 @@ static real c_b3 = 1.f;
 
     /* Local variables */
     static real r__, s, bk, ck, dk, rc, pi, th, dlm, rna;
-    extern doublereal rfpi_(void);
+    extern real rfpi_(void);
     extern /* Subroutine */ int glrget_(char *, real *, ftnlen);
-    extern doublereal xmplon_(real *);
+    extern real xmplon_(real *);
 
     switch(n__) {
 	case 1: goto L_mpicoa;
@@ -47,7 +54,7 @@ L_mpicoa:
     } else {
 	*xlon = atan2(*x, -s * *y) / dk;
     }
-    if (dabs(*xlon) <= pi) {
+    if (abs(*xlon) <= pi) {
 	rc = r__ / ck;
 	if (rc <= 1.f) {
 	    *ylat = s * (pi / 2 - asin(rc) * 2);
@@ -63,7 +70,7 @@ L_mpscoa:
     pi = rfpi_();
     glrget_("RUNDEF", &rna, (ftnlen)6);
     s = r_sign(&c_b3, ylat0);
-    bk = cos((pi / 2 - dabs(*ylat0)) / 2);
+    bk = cos((pi / 2 - abs(*ylat0)) / 2);
     ck = 2 / bk;
     dk = bk * bk;
     return 0;
