@@ -1,4 +1,4 @@
-/*  -- translated by f2c (version 20050501).
+/*  -- translated by f2c (version 20160102).
    You must link the resulting object file with libf2c:
 	on Microsoft Windows system, link with libf2c.lib;
 	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
@@ -19,12 +19,16 @@ static integer c__3 = 3;
 /* ----------------------------------------------------------------------- */
 /*     GET EXTERNAL PARAMETER FROM ENVIRONMENTAL VARIABLE */
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int rpnenv_0_(int n__, char *cpfix, char *cp, integer *ipara,
 	 logical *lpara, real *rpara, char *cpara, ftnlen cpfix_len, ftnlen 
 	cp_len, ftnlen cpara_len)
 {
+    /* Initialized data */
+
+    static char csepx[1] = "_";
+
     /* System generated locals */
     address a__1[3];
     integer i__1[3];
@@ -56,7 +60,7 @@ static integer c__3 = 3;
 
     osgenv_("DCLENVCHAR", csep, (ftnlen)10, (ftnlen)1);
     if (*(unsigned char *)csep == ' ') {
-	*(unsigned char *)csep = ':';
+	*(unsigned char *)csep = *(unsigned char *)&csepx[0];
     }
     return 0;
 /* ----------------------------------------------------------------------- */
