@@ -1,6 +1,13 @@
-/* src/math2/fftlib/passb4.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20160102).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
 #include "libtinyf2c.h"
@@ -20,7 +27,7 @@
     /* Parameter adjustments */
     ch_dim1 = *ido;
     ch_dim2 = *l1;
-    ch_offset = 1 + ch_dim1 * (1 + ch_dim2 * 1);
+    ch_offset = 1 + ch_dim1 * (1 + ch_dim2);
     ch -= ch_offset;
     cc_dim1 = *ido;
     cc_offset = 1 + cc_dim1 * 5;
