@@ -1,6 +1,13 @@
-/* src/math2/fftlib/passf.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20160102).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
 #include "libtinyf2c.h"
@@ -23,21 +30,21 @@
     /* Parameter adjustments */
     ch_dim1 = *ido;
     ch_dim2 = *l1;
-    ch_offset = 1 + ch_dim1 * (1 + ch_dim2 * 1);
+    ch_offset = 1 + ch_dim1 * (1 + ch_dim2);
     ch -= ch_offset;
     c1_dim1 = *ido;
     c1_dim2 = *l1;
-    c1_offset = 1 + c1_dim1 * (1 + c1_dim2 * 1);
+    c1_offset = 1 + c1_dim1 * (1 + c1_dim2);
     c1 -= c1_offset;
     cc_dim1 = *ido;
     cc_dim2 = *ip;
-    cc_offset = 1 + cc_dim1 * (1 + cc_dim2 * 1);
+    cc_offset = 1 + cc_dim1 * (1 + cc_dim2);
     cc -= cc_offset;
     ch2_dim1 = *idl1;
-    ch2_offset = 1 + ch2_dim1 * 1;
+    ch2_offset = 1 + ch2_dim1;
     ch2 -= ch2_offset;
     c2_dim1 = *idl1;
-    c2_offset = 1 + c2_dim1 * 1;
+    c2_offset = 1 + c2_dim1;
     c2 -= c2_offset;
     --wa;
 
