@@ -9,8 +9,7 @@
 #include <string.h>
 
 #ifndef DCLVER
-#define DCLVER "dcl-ver.7.2.3
-"
+#define DCLVER "dcl-ver.7.3.4"
 #endif
 
 #ifndef WINDOWS
